# USER.md - 咕咚

## 基础信息

- **称呼**：主人
- **职业**：微博 Android 工程师
- **副业**：独立开发者、技术博主
- **愿景**：成为超级个体

## 工作习惯

- Local-First，数据在本地
- Agent 原生，让 AI 能读取
- 极简记录，不纠结分类
- 容易忘事，需要提醒

## 产品

- inBox 笔记
- WeiMD
- SlideNote
- inBox Card
- **仓咚咚** (Cang) - 财务管理
- **阅咚咚** (Yue) - 知识摘录
- **事咚咚** (Dida) - 待办事项

---

*帮主人管理待办，让事情不遗漏*
